//-------------------------------------------------------------------------
// play-v6 - music player for ATmega328P @ 16 MHz
// instruments wave samples and ADSR parameters
// by Enrico Colombini <erix@erix.it>
// license: CC Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
// http://creativecommons.org/licenses/by-sa/4.0/
//-------------------------------------------------------------------------

#ifndef INSTRUM_H
#define INSTRUM_H

#include <stdint.h>
#include <avr/pgmspace.h>

//-------------------------------------------------------------------------
// constants

//number of samples per wave cycle
//very near to a G3 note sampled at 44100 Hz (225.00264)
#define WAVE_CYCLE          225u

//number of instruments in table
#define NUM_INSTRUMENTS     16

//-------------------------------------------------------------------------
// types

//description of an instrument
typedef struct {
    //wave samples
    const int8_t    wave[WAVE_CYCLE];
    //ADSR parameters
    const uint16_t  attackStep;
    const uint16_t  decayStep;
    const uint8_t   sustainLevel;
    const uint16_t  releaseStep;
} Instrument;

//constant pointer to Instrument in PROGMEM
typedef const Instrument * const    InstrumentConstPtr;

//-------------------------------------------------------------------------
// constant data

//exponential decay table, used by all instruments
extern const uint8_t adsrDecayTable[256] PROGMEM __attribute__ ((aligned (256)));

//table of available instruments
extern InstrumentConstPtr instruments[NUM_INSTRUMENTS] PROGMEM;

//-------------------------------------------------------------------------

#endif //INSTRUM_H
