//-------------------------------------------------------------------------
// play-v6 - music player for ATmega328P @ 16 MHz
// music commands and built-in music
// by Enrico Colombini <erix@erix.it>
// license: CC Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
// http://creativecommons.org/licenses/by-sa/4.0/
//-------------------------------------------------------------------------

#ifndef MUSIC_H
#define MUSIC_H

#include <stdint.h>
#include <avr/pgmspace.h>

//-------------------------------------------------------------------------
// constants

//right shift to get the main music command (highest 2 bits)
#define MUSCMD_MAIN_SHIFT   6

//main music commands (shifted to avoid spurious 'duplicated case' in switch)
#define MUSCMD_WAIT         0x00
#define MUSCMD_NOTE         0x01
#define MUSCMD_RELEASE      0x02
#define MUSCMD_OTHER        0x03
//for other music commands, the highest 2 bits are always set
#define MUSCMD_END          0xc0
#define MUSCMD_TEMPO        0xc1
#define MUSCMD_INSTRUMENT   0xc2

//-------------------------------------------------------------------------

//built-in music, all pieces concatenated into a single array
//each music piece starts with 16-bit length
extern const uint8_t builtinMusic[] PROGMEM;

//table of addresses of music pieces
extern const uint16_t builtinMusicList[] PROGMEM;

//number of pieces of music in the list
extern const uint8_t builtinMusicCount PROGMEM;

//-------------------------------------------------------------------------

#endif //MUSIC_H
